@@ -2,6 +2,7 @@
 These are some utilites used when writing and handling interpreters.
 '''
 
+import shutil
 from cytoplasm import configuration
 from cytoplasm.errors import InterpreterError
 
@@ -22,19 +23,13 @@ def SaveReturned(fn):
 
 def interpret(file, destination, **kwargs):
     "Interpret a file with an interpreter according to its suffix."
+    # get the list of interpreters from the configuration
     interpreters = configuration.get_config().interpreters
-    for ending in interpreters.keys():
-        # if the file has a suffix that matches any of the interpreters,
-        # parse that file with that interpreter
-        if file.endswith(".%s" %(ending)):
-            # give the interpreter two variables -- the original place and hte destination
-            # of the interpreted file.
-            try:
-                interpreters[ending](file, destination, **kwargs)
-            except Exception as exception:
-                # if the interpreter chokes, raise an InterpreterError with some useful information.
-                raise InterpreterError("%s on file '%s': %s" %(ending, file, exception))
-            handled = True
-            return True
-    return False
+    # figure out the suffix of the file, to use to determine which interpreter to use
+    ending = ".".join(file.split(".")[:-1])
+    try:
+        interpreters.get(ending, shutil.copyfile)(file, destination, **kwargs)
+    except Exception as exception:
+        # if the interpreter chokes, raise an InterpreterError with some useful information.
+        raise InterpreterError("%s on file '%s': %s" %(ending, file, exception))
 
